#!/usr/bin/env python3

__all__ = [
    'prime_divisors',
    'is_prime',
]

def divisors(number):
    """Return the list of divisors of number

    >>> divisors(10)
    [1, 2, 5, 10]
    """
    lst = []
    for i in range(1, number + 1):
        if number % i == 0:
            # divisor!
            lst.append(i)
    return lst


def is_prime(number):
    """Return True if number is prime

    >>> is_prime(2)
    True
    >>> is_prime(9)
    False
    """
    if number < 2:
        return False
    for j in range(2, number):
        if number % j == 0:
            return False
    return True


def prime_divisors(number):
    """Return the list of prime divisors of number

    >>> prime_divisors(2009)
    [7, 41]
    """
    lst = []
    for i in divisors(number):
        if is_prime(i):
            lst.append(i)
    return lst


def primes():
    """Generate all prime numbers

    >>> for dummy, p in zip(range(5), primes()):
    ...     print(p)
    ...
    2
    3
    5
    7
    11
    """
    p = 2
    while True:
        yield p
        p += 1
        while not is_prime(p):
            p += 1


if __name__ == "__main__":
    print(divisors(2009))
